<?php
/**
 * This file is part of
 * pragmaMx - Web Content Management System.
 * Copyright by pragmaMx Developer Team - http://www.pragmamx.org
 *
 * pragmaMx is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * $Revision: 1.1.2.10 $
 * $Author: siggi $
 * $Date: 2008/02/03 03:23:58 $
 *
 * Menumanager for pragmaMx, written by Siggi Braunert
 * http://www.sb-websoft.com
 **/

defined('mxMainFileLoaded') or die('access denied');

require_once(dirname(__FILE__) . '/mx_menu.db.php');
require_once('includes/mx_template.php');

class Mx_Menu extends Mx_Menu_db {
    // public
    var $nav_item = array();
    var $page = array();
    var $event = array();
    var $is_installed;
    var $message;
    var $row = array('id' => 0, 'bid' => 0, 'pid' => 0, 'title' => "", 'description' => "", 'url' => "", 'weight' => 0, 'active' => 1, 'token' => "new", 'member' => 1, 'self' => 0, 'expanded' => "");

    var $tree = array();
    var $tree_plugin = array();
    // schalter, um menue aufklappbar zu machen
    var $expandable;
    // das Template Objekt
    var $template;

    function Mx_Menu()
    {
        $path = realpath(dirname(__FILE__) . '/..');
        if (!defined('_MX_MENU_ADMIN')) {
            /* Sprachdatei auswaehlen */
            if (@file_exists($path . '/language/lang-' . $GLOBALS['currentlang'] . '.php')) {
                include_once($path . '/language/lang-' . $GLOBALS['currentlang'] . '.php');
            } else {
                include_once($path . '/language/lang-german.php');
            }
        }
        /* Konstruktor der Datenabankklasse ausfuehren */
        parent::Mx_Menu_db();
        /* Template initialisieren */
        $this->template = new Mx_Template($path . '/templates/');
        $this->expandable = $this->get_var_db('mnu_list_exp');
        if ($this->expandable == MX_LIST_EXPAND_YES) {
            $this->load_tree_plugin();
        }
    }

    function init()
    {
        $this->set_navigation();
    }

    function handleEvent()
    {
        $this->event = utils::get_admin_url();
        $this->is_installed = $this->is_installed_db();
        $this->message = ($this->is_installed == 1) ? "" : utils::message(0, _MX_MENU_INSTALL_INFO_NO);

        $this->onchange_events();

        $this->show_all_events();
        $this->add_menu_events();
        $this->add_item_events();
        $this->settings_events();
        return $this->event;
    }

    function show_all()
    {
        $menu_items = array();
        $mnu_array = array();

        $modules = $this->read_modules_db(MX_MODULES_OUT);

        $menus = $this->read_menus_db();
        foreach($menus as $menu) {
            $bid = $menu['bid'];
            $this->read_items_4showall_db($bid, 0, "", $mnu_array);
            $menu_items[$bid] = $mnu_array;
            unset($mnu_array);
        }
        if (count($menus) == 0 && $this->is_installed_db()) {
            $this->message = utils::message(1, _MX_MENU_SHOWALL_NO_MENUS);
        }
        $array = array('message' => $this->message,
            'is_installed' => $this->is_installed,
            'main_module' => mxGetMainModuleName(),
            'home' => $this->main_module_exists(),
            'menus' => $menus,
            'menu_items' => $menu_items,
            'modules' => $modules
            );
        $this->template->assign($array);
        $this->page['content'] = $this->template->fetch("show_all.html");
        $this->page['selected'] = 1;
    }

    function add_menu()
    {
        if ($this->event['menu'] == 'add_menu' || $this->event['add_menu'] == 'edit') {
            $id = (!empty($this->event['edit']) ? $this->event['edit'] : 0);
            $items = array('intro' => ($id > 0) ? sprintf(_MX_MENU_ADDMENU_BLOCKEDIT, $id) : _MX_MENU_ADDMENU_INTRO,
                'message' => $this->message,
                'is_installed' => $this->is_installed,
                'title' => ($id > 0) ? $this->get_menu_title_db($id) : "",
                'id' => $id
                );
            $this->template->assign($items);
            if ($id > 0) {
                $this->nav_item[2]['url'] = "admin.php?op=menu/add_menu/edit/$id";
                $this->nav_item[2]['title'] = _MX_MENU_ADDMENU_EDIT;
            }
            $this->page['content'] = $this->template->fetch("add_menu.html");
            $this->page['selected'] = 2;
        }
    }

    function add_item()
    {
        $sub_arr = array();
        $row = $this->row; // leeres vordefiniertes array fuer formular erzeugen

        if (!empty($this->event['add_item'])) {
            if (intval($this->event['add_item']) > 0) {
                $row['bid'] = intval($this->event['add_item']); // von show_all kommend mit vorgegeb. block id
            }

            if (is_array($this->event['add_item'])) {
                $row = $this->event['add_item']; // temp. eintraege aus formular uebernehmen
                $row['token'] = 'new';
            } elseif ($this->event['add_item'] == 'edit') {
                $id = intval($this->event['edit']);
                $row = $this->get_item_db($id); # aus db holen und in formular eintragen
                $row['member'] = intval($this->get_member($row['type']));
                $row['self'] = intval($this->get_self($row['type']));
                $row['expanded'] = intval($this->get_expanded($row['type'])) == 1 ? 'checked="checked"' : '';
                $row['token'] = 'update';
                $intro = ($row['member'] == MX_MODULE_ITEM) ? sprintf(_MX_MENU_ADDITEM_MODULEEDIT, $row['self']) : "";
                $this->nav_item[3]['url'] = "admin.php?op=menu/add_item/edit/" . $id;
                $this->nav_item[3]['title'] = _MX_MENU_ADDITEM_EDIT;
            } elseif ($this->event['add_item'] == 'module') {
                $mid = intval($this->event['module']);
                $module = $this->get_module_db($mid);
                $row['member'] = MX_MODULE_ITEM;
                $row['self'] = $mid;
                $row['expanded'] = "";
                $row['active'] = $module['active'];
                $row['title'] = $module['custom_title'];
                $row['url'] = 'modules.php?name=' . $module['title'];
                $row['description'] = $module['custom_title'];

                $row['token'] = 'new';
            }
        }

        $_menus = $this->read_menus_db();
        foreach($_menus as $_menu) {
            $bid = $_menu['bid'];
            if ($row['token'] == 'new') {
                $id = null;
            }
            $this->read_items_4select_db($id, $bid, 0, "", $sub_arr[$bid]);
        }

        $items = array('intro' => ($row['token'] == 'update') ? $intro : _MX_MENU_ADDITEM_INTRO,
            'message' => $this->message,
            'is_installed' => $this->is_installed,
            'main_module' => mxGetMainModuleName(),
            'menus' => $_menus,
            'submenus' => $sub_arr,
            'row' => $row
            );
        $this->template->assign($items);

        $this->page['content'] = $this->template->fetch("add_item.html");
        $this->page['selected'] = 3;
    }

    function settings()
    {
        $items = array('message' => $this->message,
            'is_installed' => $this->is_installed,
            'expandable' => ($this->expandable == 1) ? 'checked="checked"' : ''
            );

        $this->template->assign($items);
        $this->page['content'] = $this->template->fetch("settings.html");
        $this->page['selected'] = 4;
    }
    // private
    function set_navigation()
    {
        $this->nav_item[1]['url'] = "admin.php?op=menu";
        $this->nav_item[1]['title'] = _MX_MENU_SHOWALL;
        $this->nav_item[2]['url'] = "admin.php?op=menu/add_menu";
        $this->nav_item[2]['title'] = _MX_MENU_ADDMENU;
        $this->nav_item[3]['url'] = "admin.php?op=menu/add_item";
        $this->nav_item[3]['title'] = _MX_MENU_ADDITEM;
        $this->nav_item[4]['url'] = "admin.php?op=menu/settings";
        $this->nav_item[4]['title'] = _MX_MENU_SETTINGS;
	    
        for ($i = 1; $i <= count($this->nav_item); $i++) {
        	$this->nav_item[$i]['class'] = "";
        } 
    }

    function show_all_events()
    {
        // change_menu_status begin
        if (!empty($this->event['change_status'])) {
            $bid = $this->event['change_status'];
            $ret = $this->change_menu_status_db($bid);
            $txt = ($ret == 1) ? _MX_MENU_ENABLED : _MX_MENU_DISABLED;
            $this->message = utils::message(1, sprintf($txt, $this->title));
        }
        // change_menu_status end
        // delete_menu begin
        if (!empty($this->event['delete_menu'])) {
            $delev = $this->event['delete_menu'];
            $arr = explode(",", $delev);
            if ($arr[0] == 'id' && $arr[1] > 0) {
                $id = $arr[1];
                $title = $this->get_menu_title_db($arr[1]);
                if (empty($arr[2])) {
                    $delurl = "admin.php?op=menu/delete_menu/id," . $id . ",ok";
                    $this->message = utils::message(0, sprintf(_MX_MENU_DELETE_AREYOUSURE, $title , $delurl));
                } elseif ($arr[2] == 'ok' && $this->delete_menu_db($id) > 0) {
                    $this->message = utils::message(1, sprintf(_MX_MENU_DELETED, $title));
                }
            }
        }
        // delete_menu end
        // enable_item begin
        if (!empty($this->event['enable_item'])) {
            $id = $this->event['enable_item'];
            $title = $this->get_item_title_db($id);
            $res = $this->enable_item_db($id);
            if ($res == 1) {
                $this->message = utils::message(1, sprintf(_MX_MENU_ITEM_ENABLED, $title));
            }
        }
        // enable_item end
        // disable_item begin
        if (!empty($this->event['disable_item'])) {
            $id = $this->event['disable_item'];
            $title = $this->get_item_title_db($id);
            $res = $this->disable_item_db($id);
            if ($res == 1) {
                $this->message = utils::message(1, sprintf(_MX_MENU_ITEM_DISABLED, $title));
            }
        }
        // disable_item end
        // delete_item begin
        if (!empty($this->event['delete_item'])) {
            $delev = $this->event['delete_item'];
            $arr = explode(",", $delev);
            if ($arr[0] == 'id' && $arr[1] > 0) {
                $id = $arr[1];
                $title = $this->get_item_title_db($arr[1]);
                if (empty($arr[2])) {
                    $delurl = "admin.php?op=menu/delete_item/id," . $id . ",ok";
                    $this->message = utils::message(0, sprintf(_MX_MENU_ADDITEM_DELETE_AREYOUSURE, $title , $delurl));
                } elseif ($arr[2] == 'ok' && $this->delete_item_db($id) > 0) {
                    $this->message = utils::message(1, sprintf(_MX_MENU_ADDITEM_DELETED, $title));
                }
            }
        }
        // delete_item end
    }

    function add_menu_events()
    {
        if (isset($_POST['add_menu_form'])) {
            $add_menu_form = $_POST['add_menu_form'];
            // check title
            if (empty($add_menu_form['title'])) {
                $this->message = utils::message(0, sprintf(_MX_MENU_INPUTREQUIRED, _TITLE));
                $this->event['menu'] = 'add_menu';
            } else {
                if ($add_menu_form['id'] > 0) {
                    $do = $this->update_menu_db($add_menu_form['id'], $add_menu_form['title']);
                } else {
                    $do = $this->add_menu_db($add_menu_form['title']);
                }

                if ($do > 0) {
                    $this->message = ($add_menu_form['id'] > 0 ? utils::message(1, sprintf(_MX_MENU_ADDMENU_UPDATED, $add_menu_form['title'])) : utils::message(1, sprintf(_MX_MENU_ADDMENU_ADDED, $add_menu_form['title'])));
                    $this->event['menu'] = '';
                } elseif ($do == -1) {
                    $this->message = utils::message(0, sprintf(_MX_MENU_ADDMENU_EXISTEDALREADY, $add_menu_form['title']));
                    $this->event['menu'] = 'add_menu';
                    if ($add_menu_form['id'] > 0) {
                        $this->event['add_menu'] = 'edit';
                        $this->event['edit'] = $add_menu_form['id'];
                    }
                }
            }
        }
    }

    function add_item_events()
    {
        $msg = "";
        $do = 0;
        $marray = array();
        $tmpurl_ = array();
        if (isset($_POST['add_item_form'])) {
            $add_item_form = $_POST['add_item_form'];

            $add_item_form['expanded'] = isset($add_item_form['expanded']) ? 1 : 0;

            if (empty($add_item_form['title'])) {
                $msg .= sprintf(_MX_MENU_INPUTREQUIRED, _TITLE);
            }
            if (empty($add_item_form['url'])) {
                $msg .= ($msg == "" ? "" : "<br />");
                $msg .= sprintf(_MX_MENU_INPUTREQUIRED, _MX_MENU_PATH);
            }

            if ($msg != "") {
                $this->message = utils::message(0, $msg);
                $this->event['menu'] = 'add_item';
                $this->event['add_item'] = $add_item_form;
            } else {
                // pid aus 'bid:pid' rausholen
                $marray = explode(":", $add_item_form['bid']);
                $add_item_form['bid'] = $marray[0];
                $add_item_form['pid'] = $marray[1];
                // $add_item_form['expanded'] = isset($add_item_form['expanded']) ? 1 : 0;
                if ($add_item_form['member'] == MX_MODULE_ITEM) {
                    $add_item_form['type'] = MX_MODULE_ITEM . "|" . $add_item_form['self'] . "|" . strval($add_item_form['expanded']);
                } else {
                    $add_item_form['type'] = MX_CUSTOM_ITEM . "|0|" . strval($add_item_form['expanded']);
                }
                if ($add_item_form['token'] == 'update') {
                    $do = $this->update_item_db($add_item_form);
                } else {
                    $do = $this->add_item_db($add_item_form);
                }
            }
            if ($do > 0) {
                $this->message = ($add_item_form['token'] == 'update' ? utils::message(1, sprintf(_MX_MENU_ADDITEM_UPDATED, $add_item_form['title'])) : utils::message(1, sprintf(_MX_MENU_ADDITEM_ADDED, $add_item_form['title'])));
                $this->event['menu'] = '';
            } elseif ($do == -1) {
                $this->message = utils::message(0, sprintf(_MX_MENU_ITEM_EXISTEDALREADY, $add_item_form['title']));
                $this->event['menu'] = 'add_item';
                if ($add_item_form['token'] == 'update') {
                    $this->event['add_item'] = 'edit';
                    $this->event['edit'] = $add_item_form['id'];
                }
            }
        }
    }

    function settings_events()
    {
        if (isset($_POST['settings_form'])) {
            $settings_form = $_POST['settings_form'];
            $this->expandable = isset($settings_form['expandable']) ? MX_LIST_EXPAND_YES : MX_LIST_EXPAND_NO;
            if ($this->get_var_db('mnu_list_exp') != $this->expandable) {
                $this->set_var_db('mnu_list_exp', $this->expandable);
                if ($this->expandable == MX_LIST_EXPAND_YES) {
                    $this->load_tree_plugin();
                }
                $this->message = utils::message(1, _MX_MENU_SETTINGS_UPDATED);
                $this->event['menu'] = '';
            }
        }

        if (!empty($this->event['settings'])) {
            switch ($this->event['settings']) {
                case 'install' :
                    $this->install_db();
                    $this->message = utils::message(1, _MX_MENU_INSTALL_INFO_YES);
                    $this->event['menu'] = '';
                    break;

                case 'deinstall' :
                    if ($this->event['deinstall'] == 'ok') {
                        $this->deinstall_db();
                        $this->message = utils::message(1, _MX_MENU_DEINSTALL_INFO_YES);
                        $this->event['menu'] = '';
                    } else {
                        $this->message = utils::message(0, _MX_MENU_DEINSTALL_AREYOUSURE);
                        $this->event['menu'] = 'settings';
                    }
                    break;

                case 'reset' :
                    $this->message = utils::message(1, _MX_MENU_RESET_INFO_YES);
                    $this->event['menu'] = '';
            }
        }
    }

    function onchange_events() {
        $this->delete_abandoned_items_db();
    }
    // events end
    // ---------------------- methods to build the nested list and to show the menu -----|begin|----------------------
    /*
 function build_list_old($ul = "")
 {
  $ma = $this->tree;
  if(!is_array($ma) || count($this->tree)==0) return _MX_MENU_ADDITEM_NOTDEF;
  $diff = 0; $item = array(); $add = "";
  $count = count($ma);
  $return = empty($ul) ? "" : $ul."\n";
  $return .= "<!-- listitems start -->\n";
  for($i=0; $i<$count; $i++)
  {
   if($i > 0) {
    $diff = intval($ma[$i-1]['level']) - intval($ma[$i]['level']);
   }
   if($diff == -1) {
    $add = "<ul>\n";
   }
   elseif($diff == 0 && ($i > 0)) {
    $add = "</li>\n";
   }
   else {
    if($diff > 0) {$add = str_repeat("</li>\n</ul>\n", $diff)."</li>\n";}
   }

   $item[$i] = "<li><a href=\"".$ma[$i]['url']."\" title=\"".$ma[$i]['description']."\">".$ma[$i]['title']."</a>";
   $return .=  $add.$item[$i]."\n";
  }
  $return .= str_repeat("</li>\n</ul>\n", intval($ma[$i-1]['level']));

  $return .= "</li>\n";
  $return .= "<!-- listitems end -->\n";
  $return .= empty($ul) ? "" : "</ul>\n";
  $this->tree = array();
  return $return;
 }
 */

    function build_list($bid, $ul = "") // erweiterte Methode um das auf- und zuklappen des Menue-Trees zu ermoeglichen
    {
        static $inst = 1; // mehrere Bloecke (Instanzen) mit gleicher ID zaehlen und Tag-Identifier um $inst erweitern

        $inst++;
        $main_module = mxGetMainModuleName();
        $init = "";
        $img_close = "";
        $img_open = "";
        $focus = "";
        $notallowed_m = 0;
        $mnuopen = array();
        $ma = array();

        if (empty($this->tree)) {
            return "<li>" . _MX_MENU_ADDITEM_NOTDEF . "</li>";
        }
        foreach($this->tree as $row) {
            if ($row['member'] == MX_MODULE_ITEM && !mxModuleAllowed(substr($row['url'], 17))) {
                $notallowed_m++;
                continue;
            } else {
                $ma[] = $row;
            }
        }

        $ret = ($notallowed_m > 0 && MX_IS_ADMIN) ? "\n<li class='forbidden'>" . sprintf(_MX_MENU_ITEM_FORBIDDEN, '<b>' . $notallowed_m . '</b>') . "</li>\n" : "";
        $count = count($ma);
        if ($count == 0) {
            return "<li>" . _MX_MENU_ADDITEM_NOTDEF . "</li>\n" . $ret;
        }
        $diff = 0;
        $item = array();
        $add = "";
        $nid = "";
        $iid = "";
        $sub = "";

        $ma[$count]['level'] = $ma[$count-1]['level'];

        $return = empty($ul) ? "" : $ul . "\n";
        $return .= "<!-- listitems start -->\n";
        // ------------------- Menuepunkt von geladenem Modul immer sichtbar ---------------
        $x = 0;
        $temp_uri = substr($_SERVER['REQUEST_URI'], 1);
        $temp_count = substr_count($temp_uri, '/');
        if ($temp_count > 0) {
            for ($xx = 0; $xx < $temp_count; $xx++) {
                $temp_uri = substr(stristr($temp_uri, '/'), 1);
            }
        }
        while ($x < $count && str_replace('amp;', '', $ma[$x]['url']) != $temp_uri) {
            $x++; // geladenes Modul in der Liste ?
        }

        for($i = 0; $i < $count; $i++) {
            if ($x != $count) {
                $y = $x;
                while ($ma[$y]['level'] != 0) {
                    if ($ma[$x]['level'] != $ma[$y-1]['level']) {
                        $mnuopen[$y] = true; // wenn als Untermenuepunkt, dann darueberliegende auf jeden Fall...
                    } else $mnuopen[$y] = false;
                    $y--;
                }
            }
            // --------------------------------------------------------------------------------
            if ($i > 0) {
                $diff = intval($ma[$i-1]['level']) - intval($ma[$i]['level']);
            }
            if ($diff == -1) {
                $add = "<ul id='item_" . $inst . "_" . $bid . "_" . $ma[$i]['id'] . "' style='display:";

                if (isset($mnuopen[$i]) && $mnuopen[$i] == true) {
                    $add .= "block;'>\n"; // ...geoeffnet lassen
                } else {
                    $add .= ($ma[$i-1]['expanded'] == 0 ? 'none' : 'block') . ";'>\n";
                }
            } elseif ($diff == 0 && ($i > 0)) {
                $add = "</li>\n";
            } else {
                if ($diff > 0) {
                    $add = str_repeat("</li>\n</ul>\n", $diff) . "</li>\n";
                }
            }
            if ($ma[$i + 1]['level'] > $ma[$i]['level']) {
                $nid = "item_" . $inst . "_" . $bid . "_" . $ma[$i + 1]['id'];
                $iid = "image_" . $inst . "_" . $bid . "_" . $ma[$i + 1]['id'];
                if ($this->expandable == MX_LIST_EXPAND_YES) {
                    extract($this->tree_plugin);
                    $sub = '<img onclick="javascript:' . sprintf($init, $nid, $iid, $img_close, $img_open) . '" title="' . _MX_MENU_TREE_EXP_TITLE . '" id="' . $iid . '" src="' . ($ma[$i]['expanded'] == 0 ? $img_close : $img_open) . '" alt="' . _MX_MENU_TREE_EXP_TITLE . '" />';
                    $focus = ' onfocus="blur()"';
                }
            } else {
                $sub = "";
                $focus = "";
            }
            if (str_replace('amp;', '', $ma[$i]['url']) == $temp_uri) {
                $curr = " class='current'";
            } else {
                $curr = "";
            }

            if ($ma[$i]['url'] == "modules.php?name=" . $main_module) {
                $ma[$i]['url'] = "./";
                $ma[$i]['title'] = _HOME;
            }
            $item[$i] = "<li><a" . $curr . " href=\"" . $ma[$i]['url'] . "\" title=\"" . $ma[$i]['description'] . "\"" . $focus . ">" . $ma[$i]['title'] . $sub . "</a>";
            $return .= $add . $item[$i] . "\n";
        }
        $return .= str_repeat("</li>\n</ul>\n", intval($ma[$i-1]['level']));

        $return .= "</li>\n";
        $return .= "<!-- listitems end -->\n";
        $return .= empty($ul) ? "" : "</ul>\n";

        $this->tree = array();

        return $return . $ret;
    }

    function load_tree_plugin()
    {
        // ---------------------- startparameter fuer expandable tree ------------------------------
        $collapsed_img_path = (file_exists(MX_THEME_DIR . "/images/mx_menu/menu-collapsed.gif") ? MX_THEME_DIR . "/images/mx_menu/" : "admin/modules/mxMenu/images/mx_menu/");
        $expanded_img_path = (file_exists(MX_THEME_DIR . "/images/mx_menu/menu-expanded.gif") ? MX_THEME_DIR . "/images/mx_menu/" : "admin/modules/mxMenu/images/mx_menu/");

        $this->tree_plugin = array('init' => "mxswitch('%s', '%s', '%s', '%s'); return false;",
            'img_close' => $collapsed_img_path . "menu-collapsed.gif",
            'img_open' => $expanded_img_path . "menu-expanded.gif",
            );
        /*
  $tree_plugin         : ein array, welches wenn angegeben, das ein-und ausklappen ermoeglicht:
  - init               : das dafuer zustaendige javascript, welches 4 parameter benoetigt:
                         2 fuer die internen id's zum ansprechen der items (belegt die Methode build_list() selbst)
  - img_close, img_open: 2 fuer die symbole(angabe mit pfad) ein-und ausklappen
 */
        // ------------------------------------------------------------------------------------------
    }

    function show($bid)
    {
        $this->read_items_4block_db($bid);

        if (file_exists(MX_THEME_DIR . "/block-Menu.html")) {
            $svPath = $this->template->path;
            $this->template->path = MX_THEME_DIR . "/";
            $output = $this->template->fetch("block-Menu.html");
            $output = str_replace("{MX_MENU_LIST}", $this->build_list($bid), $output);
            $this->template->path = $svPath;
            return $output;
        } else {
            return str_replace("{MX_MENU_LIST}", $this->build_list($bid), $this->template->fetch("block-Menu.html"));
        }
    }
    // ------------------- methods to build the nested list and to show the menu ------|end|----------------------
} //endofclass Mx_Menu
class utils {
    function message($type = 1, $text)
    {
        $msg_style = "";
        switch ($type) {
            case 1:
                $msg_style = 'msg_info';
                break; # successful
            case 0:
                $msg_style = 'msg_warning';
                break; # error
        }
        return (!empty($text) ? '<div class="' . $msg_style . '">' . $text . '</div>' : '');
    }

    function get_admin_url()
    {
        $build = array();
        if (isset($_GET['op'])) {
            $op = $_GET['op'];
            $array = explode("/", $op);
            foreach($array as $key => $var) {
                if (!empty($array[$key + 1])) {
                    $build[$var] = $array[$key + 1];
                } else {
                    $build[$var] = "";
                }
            }
        }
        if (!isset($build['menu'])) {
            return false;
        } else return $build;
    }

    function checkinput($text)
    {
        // hier input filtern...
        return $text;
    }
    // ----------------- adds to prepare content from the block-modules.php ------------------
    /*
 function Content2Menu($content)
 {
  $this->links = parent::extractLinks($content);
  $this->count = count($this->links['url']);
  $this->setTags();
 }

 function getHtmlAttributeValue($str, $attr)
 {
  $retval = '';
  $pattern = sprintf("#%s\s*=\s*(?(?=['\"])['\"](\S*)['\"]|([^\s>\/>]*))#is", $attr);
  if (preg_match($pattern, $str, $matches) > 0) {
   if (isset($matches[2]) && !empty($matches[2])) {
    $retval = $matches[2];
   }
   else if (isset($matches[1]) && !empty($matches[1])) {
    $retval = $matches[1];
   }
   $retval = str_replace('"', '', $retval);
   $retval = str_replace("'", '', $retval);
  }
  return trim($retval);
 }

 function extractLinks($content)
 {
  if(preg_match_all("=<a[^>]*>(.*)</a>=siU", $content, $a))
  {
   $array = $a[1]; $i = 0;
   foreach($a[0] as $var) {
    $href = parent::getHtmlAttributeValue($var, "href");
    if(!empty($href)) {
     $links['url'][] = parent::getHtmlAttributeValue($var, "href");
     $links['title'][] = $array[$i++];
    }
   }
   return $links;
  }
  else return array();
 }
*/
    // ---------------------------------------------------------------------------
} #endofclass utils
/*
class Mx_Menu_css_loader {
    var $admin_css_file, $block_css_file, $path;

    function Mx_Menu_css_loader($path = "admin/modules/mxMenu/style/")
    {
        $this->path = $path;
    }

    function set_admin_css($file)
    // definiert alternatives admin-stylesheet file bevor die 'header.php' geladen wird
    {
        $this->admin_css_file = $file;
    }

    function set_block_css($file)
    // definiert alternatives block-stylesheet file bevor die 'header.php' geladen wird
    {
        $this->block_css_file = $file;
    }

    function init()
    // diese Funktion wird in 'header.php' aufgerufen !
    {
        $this->admin_css_file = ((empty($this->admin_css_file) || !@file_exists($this->admin_css_file)) ? $this->path . "mx_menu_admin.css" : $this->admin_css_file);
        $this->block_css_file = ((empty($this->block_css_file) || !@file_exists($this->block_css_file)) ? $this->path . "mx_menu_block.css" : $this->block_css_file);
        print '<style type="text/css" media="all">@import "' . $this->admin_css_file . '";</style>' . "\n";
        print '<style type="text/css" media="all">@import "' . $this->block_css_file . '";</style>' . "\n";
        print '<script type="text/javascript" src="admin/modules/mxMenu/style/script.js"></script>' . "\n";
        print "\n";
    }
} # endOfClass Mx_Menu_css_loader


$mx_menu_css = @new Mx_Menu_css_loader();

$theme_admin_css_file = MX_THEME_DIR . "/style/mx_menu_admin.css";
$theme_block_css_file = MX_THEME_DIR . "/style/mx_menu_block.css";

if (@file_exists($theme_admin_css_file)) {
    $mx_menu_css->set_admin_css($theme_admin_css_file); # admin css-datei vom theme einbinden
}

if (@file_exists($theme_block_css_file)) {
    $mx_menu_css->set_block_css($theme_block_css_file); # user css-datei vom theme einbinden
}
*/
?>